<?php
/**
 * @package     Joomla.Plugin
 * @subpackage  Job.jobtwo
 *
 * @copyright   Copyright (C) 2005 - 2018 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

use Joomla\Registry\Registry;

/**
 * Joomla! Log Rotation plugin
 *
 * Rotate the log files created by Joomla core
 *
 * @since  __DEPLOY_VERSION__
 */
class PlgJobJobtwo extends JPlugin
{
	/**
	 * Load the language file on instantiation.
	 *
	 * @var    boolean
	 * @since  __DEPLOY_VERSION__
	 */
	protected $autoloadLanguage = true;

	/**
	 * Application object.
	 *
	 * @var    JApplicationCms
	 * @since  __DEPLOY_VERSION__
	 */
	protected $app;

	/**
	 * Database object.
	 *
	 * @var    JDatabaseDriver
	 * @since  __DEPLOY_VERSION__
	 */
	protected $db;

	protected $status;

	/**
	 * The log check and rotation code event.
	 *
	 * @return  void
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function onExecuteScheduledTask($task = array())
	{

		$startTime = microtime(true);

		// Pseudo Lock
		if (!JPluginHelper::lock($this->_name, $this->_type, $this->status))
		{
			return;
		}

		// Get the timeout for Joomla! job jobtwo task
		$now           = time();

		$last = $this->status;
		$cache_timeout = (int) $this->params->get('cachetimeout', 1);
		$unit          = (int) $this->params->get('unit', 86400);
		$cache_timeout = ($unit * $cache_timeout);


		if ((abs($now - $last) < $cache_timeout))
		{

			// Release the lock
			JPluginHelper::unLock($this->_name, $this->_type, false);
			return;
		}

		// Execute the job ONE task
		$this->jobtwoTask();

		// Update job execution data
		$taskid = JPluginHelper::unLock($this->_name, $this->_type);

		$endTime    = microtime(true);
		$timeToLoad = sprintf('%0.2f', $endTime - $startTime);

		try
		{
			JLog::add(
				JText::sprintf('PLG_JOB_JOBTWO_END', $this->_name)  . 
				JText::sprintf('PLG_JOB_JOBTWO_TASK', $taskid) . 
				JText::sprintf('PLG_JOB_JOBTWO_PROCESS_COMPLETE', $timeToLoad),
				JLog::INFO,
				'scheduler'
			);
		}
		catch (RuntimeException $exception)
		{
			// Informational log only
		}
	}

	
	/**
	 * The log check and rotation code event.
	 *
	 * @return  void
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function jobtwoTask()
	{
		//sleep for 2 seconds
		usleep(2000000);
	}
}
